==> apache-iotdb-0.11.4-source-release.zip: apache-iotdb-0.11.4/spark-tsfile/src/main/java/org/apache/iotdb/spark/tsfile/qp/common/SingleQuery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iotdb.spark.tsfile.qp.common;


import java.util.List;

/**
 * This class is constructed with a single getIndex plan. Single getIndex means it could be processed by
 * reading API by one pass directly.<br>
 *
 */
public class SingleQuery {

  private List<FilterOperator> columnFilterOperators;
  private FilterOperator timeFilterOperator;
  private FilterOperator valueFilterOperator;

  public SingleQuery(List<FilterOperator> columnFilterOperators,
      FilterOperator timeFilter, FilterOperator valueFilter) {
    super();
    this.columnFilterOperators = columnFilterOperators;
    this.timeFilterOperator = timeFilter;
    this.valueFilterOperator = valueFilter;
  }

  public List<FilterOperator> getColumnFilterOperator() {

    return columnFilterOperators;
  }

  public FilterOperator getTimeFilterOperator() {
    return timeFilterOperator;
  }

  public FilterOperator getValueFilterOperator() {
    return valueFilterOperator;
  }

  @Override
  public String toString() {
    return "SingleQuery: \n" + columnFilterOperators + "\n" + timeFilterOperator + "\n"
        + valueFilterOperator;
  }


}

==> apache-iotdb-0.13.0-source-release.zip: apache-iotdb-0.13.0/spark-tsfile/src/main/java/org/apache/iotdb/spark/tsfile/qp/common/SingleQuery.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iotdb.spark.tsfile.qp.common;

import java.util.List;

/**
 * This class is constructed with a single getIndex plan. Single getIndex means it could be
 * processed by reading API by one pass directly.<br>
 */
public class SingleQuery {

  private List<FilterOperator> columnFilterOperators;
  private FilterOperator timeFilterOperator;
  private FilterOperator valueFilterOperator;

  public SingleQuery(
      List<FilterOperator> columnFilterOperators,
      FilterOperator timeFilter,
      FilterOperator valueFilter) {
    super();
    this.columnFilterOperators = columnFilterOperators;
    this.timeFilterOperator = timeFilter;
    this.valueFilterOperator = valueFilter;
  }

  public List<FilterOperator> getColumnFilterOperator() {

    return columnFilterOperators;
  }

  public FilterOperator getTimeFilterOperator() {
    return timeFilterOperator;
  }

  public FilterOperator getValueFilterOperator() {
    return valueFilterOperator;
  }

  @Override
  public String toString() {
    return "SingleQuery: \n"
        + columnFilterOperators
        + "\n"
        + timeFilterOperator
        + "\n"
        + valueFilterOperator;
  }
}
